@@ -2,6 +2,8 @@ import hyppo.discrim
 import hyppo.independence
 import hyppo.ksample
 import hyppo.time_series
+import hyppo.kgof
 import hyppo.tools
+import hyppo.d_variate
 
-__version__ = "0.2.2"
+__version__ = "0.3.0"
